# Configuring SAP BTP, Cloud Foundry Integration Using Trusted Certificate Authentication
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication#prerequisites)
  * [Step 1: Create or Verify the IAS Platform User](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication#step-1:-create-or-verify-the-ias-platform-user)
  * [Step 2: Create an SAP Cloud Management Service Instance and Service Key](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication#step-2:-create-an-sap-cloud-management-service-instance-and-service-key)
  * [Step 3: Add the Platform User to SAP BTP, Cloud Foundry Organizations and Spaces](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication#step-3:-add-the-platform-user-to-sap-btp,-cloud-foundry-organizations-and-spaces)
  * [Step 4: Connect LeanIX to SAP BTP, Cloud Foundry](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication#step-4:-connect-leanix-to-sap-btp,-cloud-foundry)
  * [Troubleshooting](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication#troubleshooting)
